.. include:: ../BADGES.rst

.. _pyslice_documentation:

pyslice
=======

This is the documentation for pyslice, a templating tool focused on building
data sets for simulations.

Table of Contents
-----------------
.. toctree::
   :maxdepth: 2

   readme
   manual
   contributing
   authors
   changes
   license

Other Projects
--------------
http://timcera.bitbucket.io
